;;
;; This is a cushion module to use R7RS (scheme base) from Gauche
;;
(define-module scheme.base (use r7rs-setup))
